# Changelog

All notable changes to this project will be documented in this file.

The format is based on Keep a Changelog, and this project adheres to Semantic Versioning.

## [0.1.2]

### Fixed

- terms in code filtering when multiple code in same line in `plugin.py`

## [0.1.1]

### Added

- method to search and reference glossary entries from the glossary list file in `plugin.py`